from flask import current_app, request, jsonify
from apps.view_radar import api_radar
from apps.models import *
from sqlalchemy import extract, or_, and_
from sqlalchemy.sql import func
from apps.util import login_required
from apps.utils.response_code import RET
from datetime import datetime
import datetime
from apps import db, constants, redis_store
from apps.utils.neo4j_conn import conn_neo4j

from apps.view_xiaocx import api_xiaocx


# 首页搜索
@api_xiaocx.route('/IndexSearch', methods=['POST'])
# @login_required
def index_search():
    req_dict = request.get_json()
    carrier_type = req_dict.get("carrier_type")  # 载体类型 1地块，2楼宇，3厂房，4园区，5项目
    carrier_name = req_dict.get("carrier_name")  # 载体名称
    district = req_dict.get("district")  # 所属区县
    industry = req_dict.get("industry")  # 产业类型
    investment_volume_list = req_dict.get("investment_volume_list")  # 投资额区间 [1, 0-0.5]

    nature = req_dict.get("nature")  # 土地性质
    area = req_dict.get("area")  # 土地面积 [10, 20 ]

    build_area = req_dict.get("industry")  # 建筑面积 [0, 10000]
    rent = req_dict.get("industry")  # 租金 [0, 1.5]

    zone_level = req_dict.get("zone_level")  # 园区级别

    page = req_dict.get("page")  # page
    perpage = req_dict.get("perpage")  # perpage
    data = []
    try:
        if carrier_type == 1:
            land_obj_list = ZaitiLand.query.filter(
                ZaitiLand.name == carrier_name if carrier_name else text(''),
                ZaitiLand.nature == nature if nature else text(''),
                ZaitiLand.area[0] == float(area) if area[0] else text(''),
                ZaitiLand.area[1] == float(area) if area[1] else text(''),
            ).paginate(page, perpage).items

            data = [{
                "id": land_obj.id,
                "name": land_obj.name,
                "district": land_obj.district,
                "nature": land_obj.nature,
                "area": land_obj.area,
                "lng": land_obj.lng,
                "lat": land_obj.lat,
            } for land_obj in land_obj_list]

        if carrier_type == 2:
            build_obj_list = ZaitiBuild.query.filter(
                ZaitiBuild.name == carrier_name if carrier_name else text(''),
                ZaitiBuild.attract_industry == industry if industry else text(''),
                ZaitiBuild.build_area > build_area[0] if build_area[0] else text(''),
                ZaitiBuild.build_area <= build_area[1] if build_area[1] else text(''),
                ZaitiBuild.rent > rent[0] if rent[0] else text(''),
                ZaitiBuild.rent <= rent[1] if rent[1] else text('')
            ).paginate(page, perpage).items

            data = [{
                "id": build_obj.id,
                "name": build_obj.name,
                "district": build_obj.district,
                "rent": build_obj.rent,
                "area": build_obj.build_area,
                "lng": build_obj.lng,
                "lat": build_obj.lat,
            } for build_obj in build_obj_list]

        if carrier_type == 3:
            factory_obj_list = ZaitiFactory.query.filter(
                ZaitiFactory.name == carrier_name if carrier_name else text(''),
                ZaitiFactory.attract_industry == industry if industry else text(''),
                ZaitiFactory.build_area > build_area[0] if build_area[0] else text(''),
                ZaitiFactory.build_area <= build_area[1] if build_area[1] else text('')
            ).paginate(page, perpage).items

            data = [{
                "id": factory_obj.id,
                "name": factory_obj.name,
                "district": factory_obj.district,
                "attract_industry": factory_obj.attract_industry,
                "area": factory_obj.factory_area,
                "lng": factory_obj.lng,
                "lat": factory_obj.lat,
            } for factory_obj in factory_obj_list]

        if carrier_type == 4:  # 园区
            zone_obj_list = Induzone.query.filter(
                Induzone.name == carrier_name if carrier_name else text(''),
                Induzone.navigat == industry if industry else text(''),
                Induzone.level == zone_level if zone_level else text('')
            ).paginate(page, perpage).items

            data = [{
                "id": zone_obj.id,
                "name": zone_obj.name,
                "phone": zone_obj.phone,
                "industry_position": zone_obj.industry_position,
                "district": zone_obj.district,
                "lng": zone_obj.lng,
                "lat": zone_obj.lat,
            } for zone_obj in zone_obj_list]

        if carrier_type == 5:  # 项目
            project_obj_list = Project.query.filter(
                Project.project_name == carrier_name if carrier_name else text(''),
                Project.district == district if district else text(''),
                Project.industry == industry if industry else text(''),

                Project.money > float(investment_volume_list[0]) * 10000 if investment_volume_list[0] else text(''),
                Project.money <= float(investment_volume_list[1]) * 10000 if investment_volume_list[1] else text(''),
            ).paginate(page, perpage).items

            data = [{
                "id": project_obj.id,
                "name": project_obj.name,
                "district": project_obj.district,
                "money": project_obj.money,
                "attract_industry": project_obj.attract_industry,
                "lng": project_obj.lng,
                "lat": project_obj.lat,
            } for project_obj in project_obj_list]
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="查询出错！")
    return jsonify(code=RET.OK, data=data, msg='数据查询成功！')


# 推介会列表
@api_xiaocx.route('/IntroductionMeet', methods=['POST'])
# @login_required
def introduction_meet():
    req_dict = request.get_json()
    page = req_dict.get("page")
    perpage = req_dict.get("perpage")

    try:
        meet_obj_list = IntroductionMeet.query.paginate(page, perpage).items
        meet_count = IntroductionMeet.query.count()

        data = [{
            "id": meet_obj.id,
            "name": meet_obj.name,
            "time": meet_obj.time,
            "organizer": meet_obj.organizer,
            "img_url": meet_obj.img_url,
            # "info": meet_obj.info,
        } for meet_obj in meet_obj_list]

    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="查询出错！")
    return jsonify(code=RET.OK, data={"data": data, "size": meet_count}, msg='数据查询成功！')


# 推介会详情
@api_xiaocx.route('/MeetDetail', methods=['POST'])
# @login_required
def meet_detail():
    req_dict = request.get_json()
    _id = req_dict.get("id")

    try:
        meet_obj = IntroductionMeet.query.get(_id)
        data = {
            "name": meet_obj.name,
            "time": meet_obj.time,
            "organizer": meet_obj.organizer,
            "video_url": meet_obj.video_url,
            "info": meet_obj.info
        }

    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="查询出错！")
    return jsonify(code=RET.OK, data=data, msg='数据查询成功！')


# 招商资讯列表
@api_xiaocx.route('/Information', methods=['POST'])
# @login_required
def information():
    req_dict = request.get_json()
    page = req_dict.get("page")
    perpage = req_dict.get("perpage")

    try:
        inform_obj_list = InvestmentInformation.query.paginate(page, perpage).items
        inform_count = InvestmentInformation.query.count()

        data = [{
            "name": inform_obj.name,
            "time": inform_obj.time,
            # "source": inform_obj.source,
            "info": inform_obj.info,
        } for inform_obj in inform_obj_list]

    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="查询出错！")
    return jsonify(code=RET.OK, data={"data": data, "size": inform_count}, msg='数据查询成功！')


# 招商资讯详情/最新一条时id传空
@api_xiaocx.route('/InformationDetail', methods=['POST'])
# @login_required
def information_detail():
    req_dict = request.get_json()
    _id = req_dict.get("id")

    try:
        if _id:
            inform_obj = InvestmentInformation.query.get(_id)
        else:  # 最新一条
            inform_obj = InvestmentInformation.query.order_by(
                InvestmentInformation.id.desc()
                ).all()[0]

        data = {
            "name": inform_obj.name,
            "time": inform_obj.time,
            "source": inform_obj.source,
            "info": inform_obj.info,
        }

    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="查询出错！")
    return jsonify(code=RET.OK, data=data, msg='数据查询成功！')


# 重点企业列表
@api_xiaocx.route('/CompanyList', methods=['POST'])
# @login_required
def company_list():
    req_dict = request.get_json()
    page = req_dict.get("page")
    perpage = req_dict.get("perpage")

    try:
        company_obj_list = Company.query.paginate(page, perpage).items
        company_count = Company.query.count()
        data = [{
            "id": company_obj.id,
            "name": company_obj.name
        } for company_obj in company_obj_list]

    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="查询出错！")
    return jsonify(code=RET.OK, data={"data": data, "size": company_count}, msg='数据查询成功！')


# 重点企业详情
@api_xiaocx.route('/CompanyDetail', methods=['POST'])
# @login_required
def company_detail():
    req_dict = request.get_json()
    _id = req_dict.get("id")

    try:
        company_obj = Company.query.get(_id)
        data = {
            "company_name": company_obj.company_name,
            "chain_master": company_obj.chain_master,
            "district": company_obj.district,
            "lng": company_obj.lng,
            "lat": company_obj.lat,
            "address": company_obj.address,
            "telephone": company_obj.telephone,
            "company_info": company_obj.company_info,
            "c_name": company_obj.c_name,
            "zizhi": list(filter(len, [
                '是否高新技术企业' if company_obj.high_new == '1' else '',
                '是否科技型中小企业' if company_obj.tbe == '1' else '',
                '是否为省级民营科技企业' if company_obj.tbe_sjmy == '1' else '',
                '是否为有融资企业' if company_obj.fianacing == '1' else '',
                '是否上市企业' if company_obj.quoted_company == '1' else '',
                '是否为有专利企业' if company_obj.patent == '1' else '',
                '是否山西民营100强' if company_obj.sxmon == '1' else '',
                '是否为山西专精特新企业' if company_obj.zjtg == '1' else '',
                '是否为国家级专精特新小巨人企业' if company_obj.zjtg_gjjxjr == '1' else '',
                '是否为省级专精特新小巨人企业' if company_obj.zjtg_sjxjr == '1' else '',
                '独角兽企业' if company_obj.unicorn == '1' else '',
                '瞪羚' if company_obj.dengl == '1' else '',
                '是否中国500强' if company_obj.isfive == '1' else '',
                '是否山西100强' if company_obj.sxonhun == '1' else '',
                '规模以上企业' if company_obj.scale == '1' else '',
                '限额以上服务业' if company_obj.serve == '1' else ''
            ]))
        }

    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="查询出错！")
    return jsonify(code=RET.OK, data=data, msg='数据查询成功！')


# 地块详情
@api_xiaocx.route('/ZaitiDetail', methods=['POST'])
# @login_required
def zaiti_detail():
    req_dict = request.get_json()
    flag = req_dict.get("flag")  # 1地块，2楼宇，3厂房，4园区， 5项目
    _id = req_dict.get("id")

    try:
        if flag == 1:
            land_obj = ZaitiLand.query.get(_id)
            data = {
                "name": land_obj.name,
                "lng": land_obj.lng,
                "lat": land_obj.lat,
                "district": land_obj.district,
                "location": land_obj.location,
                "nature": land_obj.nature,
                "plot_ratio": land_obj.plot_ratio,
                "develop_degree": land_obj.develop_degree,
                "linkman": land_obj.linkman,
                "telephone": land_obj.telephone
            }

        if flag == 2:
            build_obj = ZaitiBuild.query.get(_id)
            data = {
                "name": build_obj.name,
                "lng": build_obj.lng,
                "lat": build_obj.lat,
                "district": build_obj.district,
                "address": build_obj.address,
                "build_area": build_obj.build_area,
                "attract_industry": build_obj.attract_industry,
                "rent": build_obj.rent,
                "linkman": build_obj.linkman,
                "telephone": build_obj.telephone
            }

        if flag == 3:
            factory_obj = ZaitiFactory.query.get(_id)
            data = {
                "name": factory_obj.name,
                "lng": factory_obj.lng,
                "lat": factory_obj.lat,
                "district": factory_obj.district,
                "address": factory_obj.address,
                "land_area": factory_obj.land_area,
                "build_area": factory_obj.build_area,
                "empty_area": factory_obj.empty_area,
                "factory_structure": factory_obj.factory_structure,
                "width": factory_obj.width,
                "high": factory_obj.high,
                "attract_industry": factory_obj.attract_industry,
                "rent": factory_obj.rent,
                "linkman": factory_obj.linkman,
                "telephone": factory_obj.telephone
            }
    except Exception as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="查询出错！")
    return jsonify(code=RET.OK, data=data, msg='数据查询成功！')


# 投资咨询
@api_xiaocx.route('/Consultation', methods=['POST'])
# @login_required
def consultation():
    req_dict = request.get_json()
    project_name = req_dict.get("project_name")
    investor = req_dict.get("investor")
    investor_place = req_dict.get("investor_place")
    project_type = req_dict.get("project_type")
    investment_volume = req_dict.get("investment_volume")
    basic_information = req_dict.get("basic_information")
    land_area = req_dict.get("land_area")

    try:
        cons_obj = CustomerConsultation()
        cons_obj.project_name = project_name
        cons_obj.investor = investor
        cons_obj.investor_place = investor_place
        cons_obj.project_type = project_type
        cons_obj.investment_volume = investment_volume
        cons_obj.basic_information = basic_information
        cons_obj.land_area = land_area
        cons_obj.flag = 0
        db.session.add(cons_obj)
        db.session.commit()
    except Enterprise as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="查询出错！")
    return jsonify(code=RET.OK, msg='保存成功！')


# 投资咨询信息展示
@api_xiaocx.route('/GetConsultation', methods=['POST'])
# @login_required
def get_consultation():
    req_dict = request.get_json()
    page = req_dict.get("page")
    perpage = req_dict.get("perpage")
    try:
        cons_obj_list = CustomerConsultation.query.paginate(page, perpage).items
        cons_count = CustomerConsultation.query.count()
        data = [{
            "project_name": cons_obj.project_name,
            "investor": cons_obj.investor,
            "investor_place": cons_obj.investor_place,
            "project_type": cons_obj.project_type,
            "investment_volume": cons_obj.investment_volume,
            "basic_information": cons_obj.basic_information,
            "land_area": cons_obj.land_area,
            "flag": cons_obj.flag,
            "reply_content": cons_obj.reply_content,
        } for cons_obj in cons_obj_list]

    except Enterprise as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="查询出错！")
    return jsonify(code=RET.OK, data={"data": data, "size": cons_count}, msg='查询成功！')


# 回复投资咨询
@api_xiaocx.route('/ReplyConsultation', methods=['POST'])
# @login_required
def reply_consultation():
    req_dict = request.get_json()
    reply_content = req_dict.get("reply_content")
    _id = req_dict.get("id")
    try:
        cons_obj = CustomerConsultation.query.get(_id)
        cons_obj.reply_content = reply_content
        db.session.commit()

    except Enterprise as e:
        current_app.logger.error(e)
        return jsonify(code=RET.SESSIONERR, msg="回复信息保存出错！")
    return jsonify(code=RET.OK, msg='回复信息保存成功。')

